API Reference
=============

This section contains the complete API reference for oduit.

Core Modules
------------

.. toctree::
   :maxdepth: 2

   api/process_manager
   api/config_loader
   api/odoo_operations
   api/odoo_code_executor
   api/module_manager
   api/manifest
   api/manifest_collection
   api/addons_path_manager
   api/demo_process_manager

Command Line Interface
----------------------

.. toctree::
   :maxdepth: 2

   api/cli_typer
   api/cli_types

Utilities
---------

.. toctree::
   :maxdepth: 2

   api/operation_result
   api/output
   api/exceptions
   api/builders
   api/utils

Complete API
------------

.. toctree::
   :maxdepth: 1

   api/modules
